package io.vaadinpush.issuereprod.pageRoute.base

import com.vaadin.flow.component.DetachEvent
import com.vaadin.flow.component.dialog.Dialog
import com.vaadin.flow.component.notification.Notification
import com.vaadin.flow.router.*
import com.vaadin.flow.theme.lumo.Lumo
import io.vaadinpush.issuereprod.util.extension.cancelQuietly
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers

open class BaseAppLayoutView() : BaseAppLayoutCoroutineScopedView(), BeforeEnterObserver, BeforeLeaveObserver, AfterNavigationObserver {

    protected open val TAG = "BaseAppLayoutView"

    protected val viewScope: CoroutineScope by lazy {
        CoroutineScope(Dispatchers.Default)
    }

    protected var themeVariant: String = Lumo.LIGHT
    protected val isThemeLight: Boolean
        get() = themeVariant.equals(Lumo.LIGHT, true)

    protected val isThemeDark: Boolean
        get() = themeVariant.equals(Lumo.DARK, true)

    protected var dialogCookieConsent: Dialog? = null
    protected var notification: Notification? = null
    protected var dialog: Dialog? = null

    init {

    }

    override fun onDetach(detachEvent: DetachEvent?) {

        notification?.close()
        notification = null

        dialogCookieConsent?.close()
        dialogCookieConsent = null

        dialog?.close()
        dialog = null

        viewScope.cancelQuietly("onDetach")
        super.onDetach(detachEvent)
    }



    override fun afterNavigation(event: AfterNavigationEvent?) {

    }

    override fun beforeEnter(event: BeforeEnterEvent?) {

    }

    override fun beforeLeave(event: BeforeLeaveEvent?) {

    }
}