package io.vaadinpush.issuereprod.pageRoute.home

import com.vaadin.flow.component.AttachEvent
import com.vaadin.flow.component.DetachEvent
import com.vaadin.flow.component.button.Button
import com.vaadin.flow.component.grid.Grid
import com.vaadin.flow.component.html.Image
import com.vaadin.flow.component.html.Span
import com.vaadin.flow.component.orderedlayout.*
import com.vaadin.flow.component.upload.Upload
import com.vaadin.flow.component.upload.receivers.MultiFileBuffer
import com.vaadin.flow.data.renderer.ComponentRenderer
import com.vaadin.flow.dom.Style
import com.vaadin.flow.i18n.LocaleChangeEvent
import com.vaadin.flow.i18n.LocaleChangeObserver
import com.vaadin.flow.router.*
import com.vaadin.flow.server.VaadinSession
import com.vaadin.quarkus.annotation.UIScoped
import io.vaadinpush.issuereprod.data.constants.PageRoutes
import io.vaadinpush.issuereprod.pageRoute.base.BaseView
import io.vaadinpush.issuereprod.pageRoute.main.MainPage
import kotlinx.coroutines.ensureActive
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch
import org.apache.commons.io.FileUtils


@ExperimentalStdlibApi
@Route(value = PageRoutes.HOME, registerAtStartup = true, layout = MainPage::class)
@UIScoped // https://vaadin.com/docs/latest/flow/integrations/spring/scopes
open class HomePage(): BaseView(true), BeforeEnterObserver, BeforeLeaveObserver,
    AfterNavigationObserver {

    private var uploadFileBuffer: MultiFileBuffer? = null

    private var viewModel: HomePageViewModel? = null

    override fun onAttach(attachEvent: AttachEvent?) {
        super.onAttach(attachEvent)


        logger.error("pushMode -> ${VaadinSession.getCurrent().configuration.pushMode}")
        viewModel = HomePageViewModel(VaadinSession.getCurrent().session.id, VaadinSession.getCurrent().locale,VaadinSession.getCurrent().browser)
        viewModel?.onAttach(attachEvent)

        val mainLayout = HorizontalLayout()
        mainLayout.setSizeFull()
        mainLayout.style.set("border-inline-end", "none")

        mainLayout.isPadding = false
        mainLayout.isMargin = false
        mainLayout.isSpacing = false
        mainLayout.alignItems = FlexComponent.Alignment.CENTER
        mainLayout.justifyContentMode = FlexComponent.JustifyContentMode.CENTER

        val mainContentLayout = VerticalLayout()
        mainContentLayout.setSizeUndefined()

        mainContentLayout.setWidthFull()
        mainContentLayout.alignItems = FlexComponent.Alignment.CENTER
        mainContentLayout.justifyContentMode = FlexComponent.JustifyContentMode.CENTER

        val button = Button("CLICK to receive all push UI changes")

        val counterSpan = Span()
        mainContentLayout.add(counterSpan)
        mainContentLayout.add(button)

        val scrollerMain = Scroller()
        scrollerMain.scrollDirection = Scroller.ScrollDirection.VERTICAL

        scrollerMain.addThemeVariants(ScrollerVariant.LUMO_OVERFLOW_INDICATORS)

        scrollerMain.content = mainContentLayout

        mainLayout.add(scrollerMain)

        add(mainLayout)

        launch {
            ensureActive()

            launch {
                ensureActive()
                viewModel?.getCounterValueList()?.collectLatest { value ->

                   counterSpan.text = value.joinToString(separator = ", ")
                    logger.error("getCounterValueList / newestValue -> ${value.lastOrNull()}")
                    logger.error("getCounterValueList / counterSpan.text -> ${counterSpan.text}")
                }
            }

        }

    }

    override fun onDetach(detachEvent: DetachEvent?) {
        viewModel?.onDetach(detachEvent)
        viewModel = null
        super.onDetach(detachEvent)
    }

    override fun afterNavigation(event: AfterNavigationEvent?) {


    }

    override fun beforeEnter(event: BeforeEnterEvent?) {

    }

    override fun beforeLeave(event: BeforeLeaveEvent?) {

    }
}