package io.vaadinpush.issuereprod.util.extension

import java.io.File
import java.net.http.HttpRequest
import java.nio.charset.StandardCharsets
import java.nio.file.Files
import java.nio.file.Path

fun HttpRequest.Builder.postMultipartFormData(boundary: String, data: List<Pair<String, Any>>): HttpRequest.Builder {
    val byteArrays = ArrayList<ByteArray>()
    val separator = "--$boundary\r\nContent-Disposition: form-data; name=".toByteArray(StandardCharsets.UTF_8)
    data.forEach { pair ->
        byteArrays.add(separator)
        when(pair.second) {
            is File -> {
                val file = pair.second as File
                val path = Path.of(file.toURI())
                val mimeType = Files.probeContentType(path)
                byteArrays.add("\"${pair.first}\"; filename=\"${path.fileName}\"\r\nContent-Type: $mimeType\r\n\r\n".toByteArray(StandardCharsets.UTF_8))
                byteArrays.add(Files.readAllBytes(path))
                byteArrays.add("\r\n".toByteArray(StandardCharsets.UTF_8))
            }
            else -> byteArrays.add("\"${pair.first}\"\r\n\r\n${pair.second}\r\n".toByteArray(StandardCharsets.UTF_8))
        }
    }

    byteArrays.add("--$boundary--".toByteArray(StandardCharsets.UTF_8))

    this.header("Content-Type", "multipart/form-data;boundary=$boundary")
        .POST(HttpRequest.BodyPublishers.ofByteArrays(byteArrays))
    return this

}