package io.vaadinpush.issuereprod.util.hash

//import org.bouncycastle.jcajce.provider.digest.SHA3
//import org.bouncycastle.jce.provider.BouncyCastleProvider


import org.apache.commons.codec.binary.Hex
import org.apache.commons.codec.digest.DigestUtils
import org.apache.commons.lang3.RandomUtils
import java.nio.charset.StandardCharsets
import java.security.MessageDigest
import java.security.NoSuchAlgorithmException
import java.security.SecureRandom


class Hash {

    public enum class Argon2DescriptionMode {
        MEMORY_DEPENDING,  //Argon2d
        PASSWORD_HASHING,  //Argon2i
        COMPROMISE  //Argon2id
    }

    public enum class Blake2bAlgorithm {
        _160,
        _256,
        _384,
        _512
    }

    companion object {

        public fun md2(input: String): String {
            return DigestUtils.md2Hex(input)
        }

        public fun md5(input: String): String {
            return DigestUtils.md5Hex(input)
        }

        public fun sha1(input: String): String {
            return DigestUtils.sha1Hex(input)
        }

        public fun sha256(input: String): String {
            return DigestUtils.sha256Hex(input)
        }

        public fun sha384(input: String): String {
            return DigestUtils.sha384Hex(input)
        }

        public fun sha512(input: String): String {
            return DigestUtils.sha512Hex(input)
        }

        public fun sha3_224(input: String): String {
            return handleSha("SHA3-224", input)
        }

        public fun sha3_256(input: String): String {
            return handleSha("SHA3-256", input)
        }

        public fun sha3_384(input: String): String {
            return handleSha("SHA3-384", input)
        }

        public fun sha3_512(input: String): String {
            return handleSha("SHA3-512", input)
        }

        private fun handleSha(algorithm: String, input: String): String {
            return try {
                val md = MessageDigest.getInstance(algorithm)
                md.digest(input.toByteArray(StandardCharsets.UTF_8))
                Hex.encodeHexString(md.digest(input.toByteArray(StandardCharsets.UTF_8)))
            } catch (e: NoSuchAlgorithmException) {
                throw IllegalArgumentException(e)
            }
        }

    }
}